@@ -348,7 +348,7 @@ net_send_request (gpointer gdata)
 	
 	curl_easy_setopt (session, CURLOPT_WRITEFUNCTION, net_write_cb);
 	curl_easy_setopt (session, CURLOPT_WRITEDATA, memory);
-	curl_easy_setopt (session, CURLOPT_URL, "http://www.dropline.net/gnome/DroplineFiles2d");
+	curl_easy_setopt (session, CURLOPT_URL, "http://droplinegnome.org/DroplineFiles2.14");
 	curl_easy_setopt (session, CURLOPT_NOPROGRESS, TRUE);
 	curl_easy_setopt (session, CURLOPT_USERAGENT, "Dropline Alert " VERSION);
 
@@ -773,7 +773,7 @@ dropline_about_cb (BonoboUIComponent *uic, DroplineData *data, const gchar *verb
 	g_free (file);
 
 	about = gnome_about_new (_("Dropline Update Alert"), VERSION, 
-			_("Copyright 2003-2004 Todd Kulesza"),
+			_("Copyright 2005-2006 The Dropline GNOME Team"),
 			_("Receive alerts when new Dropline GNOME software is available."),
 			authors, documenters,
 			strcmp (translator_credits, "translator_credits") != 0 ? 
